/*============================================================================
 *
 *                    Code_Saturne version 1.3
 *                    ------------------------
 *
 *
 *     This file is part of the Code_Saturne Kernel, element of the
 *     Code_Saturne CFD tool.
 *
 *     Copyright (C) 1998-2008 EDF S.A., France
 *
 *     contact: saturne-support@edf.fr
 *
 *     The Code_Saturne Kernel is free software; you can redistribute it
 *     and/or modify it under the terms of the GNU General Public License
 *     as published by the Free Software Foundation; either version 2 of
 *     the License, or (at your option) any later version.
 *
 *     The Code_Saturne Kernel is distributed in the hope that it will be
 *     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 *     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with the Code_Saturne Kernel; if not, write to the
 *     Free Software Foundation, Inc.,
 *     51 Franklin St, Fifth Floor,
 *     Boston, MA  02110-1301  USA
 *
 *============================================================================*/

#ifndef __CS_COUPLAGE_H__
#define __CS_COUPLAGE_H__

/*============================================================================
 * Dfinitions, variables globales, et fonctions associes aux couplages
 * du code avec lui-mme ou avec des modules reconnus.
 *============================================================================*/

/*----------------------------------------------------------------------------
 *  Fichiers `include' librairie standard C
 *----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------
 *  Fichiers `include' locaux
 *----------------------------------------------------------------------------*/

#include "cs_base.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*============================================================================
 * Dfinitions d'numerations
 *============================================================================*/


/*============================================================================
 * Dfinition de macros
 *============================================================================*/


/*============================================================================
 * Dclaration de structures
 *============================================================================*/

/*
  Pointeur associ  un couplage. La structure elle-mme est dclare
  dans le fichier "cs_couplage.c", car elle n'est pas ncessaire ailleurs.
*/

typedef struct _cs_couplage_t cs_couplage_t;


/*============================================================================
 * Fonctions publiques pour API Fortran
 *============================================================================*/

/*----------------------------------------------------------------------------
 * Rcupration du nombre de cas de couplage
 *
 * Interface Fortran :
 *
 * SUBROUTINE NBCCPL
 * *****************
 *
 * INTEGER          NBRCPL         : <-- : nombre de couplages
 *----------------------------------------------------------------------------*/

void CS_PROCF (nbccpl, NBCCPL)
(
 cs_int_t  *const nbrcpl              /* <-- nombre de couplages              */
);


/*----------------------------------------------------------------------------
 * Affectation des listes de cellules et de faces de bord associes 
 * un couplage, ainsi que d'un ensemble de points.
 *
 * Les cellules et faces de bord locales "support" servent de base de
 * localisation des valeurs aux cellules et faces "couple" distantes.
 * Selon le rle metteur et/ou destinataire du processus courant dans le
 * couplage, certains de ces ensembles peuvent tre vides ou non.
 *
 * Les valeurs aux cellules seront toujours localises et interpoles
 * par rapport au support "cellules" distant. Les valeurs aux faces
 * de bord seront localises et interpoles par rapport au support
 * "faces de bord" s'il existe, et par rapport au support "cellules"
 * sinon. Vu du processeur local, on affecte (gnralement par
 * interpolation) des valeurs  0  2 ensembles de points distants,
 * dont l'un prendra les valeurs bases sur les cellules, et l'autre
 * soit sur les cellules, soit sur les faces de bord (selon si l'on
 * a dfini les faces de bord comme support ou non).
 *
 * Si les tableaux LCESUP et LFBSUP ne sont pas tris en entre, ils
 * le seront en sortie
 *
 * Interface Fortran :
 *
 * SUBROUTINE DEFCPL
 * *****************
 *
 * INTEGER          NUMCPL         : --> : numro du couplage
 * INTEGER          NCESUP         : --> : nombre de cellules support
 * INTEGER          NFBSUP         : --> : nombre de faces de bord support
 * INTEGER          NCECPL         : --> : nombre de cellules couples
 * INTEGER          NFBCPL         : --> : nombre de faces de bord couples
 * INTEGER          LCESUP(NCESUP) : --> : liste des cellules support
 * INTEGER          LFBSUP(NFBSUP) : --> : liste des faces de bord support
 * INTEGER          LCECPL(NCECPL) : --> : liste des cellules couples
 * INTEGER          LFBCPL(NFBCPL) : --> : liste des faces de bord couples
 *----------------------------------------------------------------------------*/

void CS_PROCF (defcpl, DEFCPL)
(
 const cs_int_t  *const numcpl,       /* --> numro du couplage               */
 const cs_int_t  *const ncesup,       /* --> nombre de cellules support       */
 const cs_int_t  *const nfbsup,       /* --> nombre de faces de bord support  */
 const cs_int_t  *const ncecpl,       /* --> nombre de cellules couples      */
 const cs_int_t  *const nfbcpl,       /* --> nombre de faces de bord couples */
       cs_int_t         lcesup[],     /* <-> liste des cellules support       */
       cs_int_t         lfbsup[],     /* <-> liste des faces de bord support  */
 const cs_int_t         lcecpl[],     /* --> liste des cellules couples      */
 const cs_int_t         lfbcpl[]      /* --> liste des faces de bord couples */
);


/*----------------------------------------------------------------------------
 * Rcupration des nombres de cellules et faces de bord support, couples,
 * et non localises associes  un couplage
 *
 * Interface Fortran :
 *
 * SUBROUTINE NBECPL
 * *****************
 *
 * INTEGER          NUMCPL         : --> : numro du couplage
 * INTEGER          NCESUP         : <-- : nombre de cellules support
 * INTEGER          NFBSUP         : <-- : nombre de faces de bord support
 * INTEGER          NCECPL         : <-- : nombre de cellules couples
 * INTEGER          NFBCPL         : <-- : nombre de faces de bord couples
 * INTEGER          NCENCP         : <-- : nombre de cellules non couples
 *                                 :     : car non localises
 * INTEGER          NFBNCP         : <-- : nombre de faces de bord non
 *                                 :     : couples car non localises
 *----------------------------------------------------------------------------*/

void CS_PROCF (nbecpl, NBECPL)
(
 const cs_int_t  *const numcpl,       /* --> numro du couplage               */
       cs_int_t  *const ncesup,       /* <-- nombre de cellules support       */
       cs_int_t  *const nfbsup,       /* <-- nombre de faces de bord support  */
       cs_int_t  *const ncecpl,       /* <-- nombre de cellules couples      */
       cs_int_t  *const nfbcpl,       /* <-- nombre de faces de bord couples */
       cs_int_t  *const ncencp,       /* <-- nombre de cellules non couples
                                       *     car non localises               */
       cs_int_t  *const nfbncp        /* <-- nombre de faces de bord non
                                       *     couples car non localises      */
);


/*----------------------------------------------------------------------------
 * Rcupration des listes de cellules et de faces de bord couples
 * (i.e. rceptrices) associes  un couplage.
 *
 * Le nombre de cellules et faces de bord, obtenus via NBECPL(), sont
 * fournis  des fins de vrification de cohrence des arguments.
 *
 * Interface Fortran :
 *
 * SUBROUTINE LELCPL
 * *****************
 *
 * INTEGER          NUMCPL         : --> : numro du couplage
 * INTEGER          NCECPL         : --> : nombre de cellules couples
 * INTEGER          NFBCPL         : --> : nombre de faces de bord couples
 * INTEGER          LCECPL(*)      : <-- : liste des cellules couples
 * INTEGER          LFBCPL(*)      : <-- : liste des faces de bord couples
 *----------------------------------------------------------------------------*/

void CS_PROCF (lelcpl, LELCPL)
(
 const cs_int_t  *const numcpl,       /* --> numro du cas de couplage        */
 const cs_int_t  *const ncecpl,       /* --> nombre de cellules couples      */
 const cs_int_t  *const nfbcpl,       /* --> nombre de faces de bord couples */
       cs_int_t  *const lcecpl,       /* <-- liste des cellules couples      */
       cs_int_t  *const lfbcpl        /* <-- liste des faces de bord couples */
);


/*----------------------------------------------------------------------------
 * Rcupration des listes de cellules et de faces de bord non couples
 * (i.e. rceptrices mais non localises) associes  un couplage
 *
 * Le nombre de cellules et faces de bord, obtenus via NBECPL(), sont
 * fournis  des fins de vrification de cohrence des arguments.
 *
 * Interface Fortran :
 *
 * SUBROUTINE LENCPL
 * *****************
 *
 * INTEGER          NUMCPL         : --> : numro du couplage
 * INTEGER          NCENCP         : <-- : nombre de cellules non couples
 *                                 :     : car non localises
 * INTEGER          NFBNCP         : <-- : nombre de faces de bord non
 *                                 :     : couples car non localises
 * INTEGER          LCENCP(*)      : <-- : liste des cellules non couples
 * INTEGER          LFBNCP(*)      : <-- : liste des faces de bord non couples
 *----------------------------------------------------------------------------*/

void CS_PROCF (lencpl, LENCPL)
(
 const cs_int_t  *const numcpl,       /* --> numro du cas de couplage        */
 const cs_int_t  *const ncencp,       /* --> nombre de cellules non couples
                                       *     car non localises               */
 const cs_int_t  *const nfbncp,       /* --> nombre de faces de bord non
                                       *     couples car non localises      */
       cs_int_t  *const lcencp,       /* <-- liste des cellules non couples  */
       cs_int_t  *const lfbncp        /* <-- liste des faces de bord non
                                       *     couples                         */
);


/*----------------------------------------------------------------------------
 * Rcupration du nombre de points distants associs  un couplage
 * et localiss par rapport au domaine local
 *
 * Interface Fortran :
 *
 * SUBROUTINE NPDCPL
 * *****************
 *
 * INTEGER          NUMCPL         : --> : numro du couplage
 * INTEGER          NCEDIS         : <-- : nombre de cellules distantes
 * INTEGER          NFBDIS         : <-- : nombre de faces de bord distantes
 *----------------------------------------------------------------------------*/

void CS_PROCF (npdcpl, NPDCPL)
(
 const cs_int_t  *const numcpl,       /* --> numro du couplage               */
       cs_int_t  *const ncedis,       /* <-- nombre de cellules distantes     */
       cs_int_t  *const nfbdis        /* <-- nombre de faces de bord dist.    */
);


/*----------------------------------------------------------------------------
 * Rcupration des coordonnes des points distants affects  un
 * couplage et une liste de points, ainsi que les numros et le
 * type d'lment (cellules ou faces) "contenant" ces points.
 *
 * Le nombre de points distants NBRPTS doit tre gal  l'un des arguments
 * NCEDIS ou NFBDIS retourns par NPDCPL(), et est fourni ici  des fins
 * de vrification de cohrence avec les arguments NUMCPL et ITYSUP.
 *
 * Interface Fortran :
 *
 * SUBROUTINE COOCPL
 * *****************
 *
 * INTEGER          NUMCPL         : --> : numro du couplage
 * INTEGER          NBRPTS         : --> : nombre de points distants
 * INTEGER          ITYDIS         : --> : 1 : accs aux points affects
 *                                 :     :     aux cellules distantes
 *                                 :     : 2 : accs aux points affects
 *                                 :     :     aux faces de bord distantes
 * INTEGER          ITYLOC         : <-- : 1 : localisation par rapport
 *                                 :     :     aux cellules locales
 *                                 :     : 2 : localisation par rapport
 *                                 :     :     aux faces de bord locales
 * INTEGER          LOCPTS(*)      : <-- : numro du "contenant" associ 
 *                                 :     :   chaque point
 * DOUBLE PRECISION COOPTS(3,*)    : <-- : coordonnes des points distants
 *----------------------------------------------------------------------------*/

void CS_PROCF (coocpl, COOCPL)
(
 const cs_int_t  *const numcpl,       /* --> numro du couplage               */
 const cs_int_t  *const nbrpts,       /* --> nombre de points distants        */
 const cs_int_t  *const itydis,       /* --> 1 : accs aux points affects
                                       *         aux cellules distantes
                                       *     2 : accs aux points affects
                                       *         aux faces de bord distantes  */
       cs_int_t  *const ityloc,       /* <-- 1 : localisation par rapport
                                       *         aux cellules locales
                                       *     2 : localisation par rapport
                                       *         aux faces de bord locales    */
       cs_int_t  *const locpts,       /* <-- liste des mailles associes      */
       cs_real_t *const coopts        /* <-- coord. des points  localiser    */
);


/*----------------------------------------------------------------------------
 * Echange d'une variable associe  un ensemble de points et  un couplage.
 *
 * Interface Fortran :
 *
 * SUBROUTINE VARCPL
 * *****************
 *
 * INTEGER          NUMCPL         : --> : numro du couplage
 * INTEGER          NBRDIS         : --> : Nombre de valeurs  envoyer
 * INTEGER          NBRLOC         : --> : Nombre de valeurs  recevoir
 * INTEGER          ITYVAR         : --> : 1 : variables aux cellules
 *                                 :     : 2 : variables aux faces de bord
 * DOUBLE PRECISION VARDIS(*) )    : --> : variable distante ( envoyer)
 * DOUBLE PRECISION VARLOC(*) )    : <-- : variable locale ( recevoir)
 *----------------------------------------------------------------------------*/

void CS_PROCF (varcpl, VARCPL)
(
 const cs_int_t  *const numcpl,       /* --> numro du couplage               */
 const cs_int_t  *const nbrdis,       /* --> nombre de valeurs  envoyer      */
 const cs_int_t  *const nbrloc,       /* --> nombre de valeurs  recevoir     */
 const cs_int_t  *const ityvar,       /* --> 1 : variables aux cellules
                                       *     2 : variables aux faces de bord  */
       cs_real_t *const vardis,       /* --> variable distante ( envoyer)    */
       cs_real_t *const varloc        /* <-- variable locale ( recevoir)     */
);


/*----------------------------------------------------------------------------
 * Echange de tableaux d'entiers associs  un couplage.
 *
 * On suppose que les tableaux  changer sont de mme taille et contiennent
 * les mmes valeurs sur chaque groupe de processus (locaux et distants).
 *
 * Interface Fortran :
 *
 * SUBROUTINE TBICPL
 * *****************
 *
 * INTEGER          NUMCPL         : --> : numro du couplage
 * INTEGER          NBRDIS         : --> : Nombre de valeurs  envoyer
 * INTEGER          NBRLOC         : --> : Nombre de valeurs  recevoir
 * INTEGER          TABDIS(*) )    : --> : valeurs distantes ( envoyer)
 * INTEGER          TABLOC(*) )    : --> : valeurs locales ( recevoir)
 *----------------------------------------------------------------------------*/

void CS_PROCF (tbicpl, TBICPL)
(
 const cs_int_t  *const numcpl,       /* --> numro du couplage               */
 const cs_int_t  *const nbrdis,       /* --> nombre de valeurs  envoyer      */
 const cs_int_t  *const nbrloc,       /* --> nombre de valeurs  recevoir     */
       cs_int_t  *const vardis,       /* --> variable distante ( envoyer)    */
       cs_int_t  *const varloc        /* <-- variable locale ( recevoir)     */
);


/*----------------------------------------------------------------------------
 * Echange de tableaux de rels associs  un couplage.
 *
 * On suppose que les tableaux  changer sont de mme taille et contiennent
 * les mmes valeurs sur chaque groupe de processus (locaux et distants).
 *
 * Interface Fortran :
 *
 * SUBROUTINE TBRCPL
 * *****************
 *
 * INTEGER          NUMCPL         : --> : numro du couplage
 * INTEGER          NBRDIS         : --> : Nombre de valeurs  envoyer
 * INTEGER          NBRLOC         : --> : Nombre de valeurs  recevoir
 * DOUBLE PRECISION TABDIS(*) )    : --> : valeurs distantes ( envoyer)
 * DOUBLE PRECISION TABLOC(*) )    : --> : valeurs locales ( recevoir)
 *----------------------------------------------------------------------------*/

void CS_PROCF (tbrcpl, TBRCPL)
(
 const cs_int_t  *const numcpl,       /* --> numro du couplage               */
 const cs_int_t  *const nbrdis,       /* --> nombre de valeurs  envoyer      */
 const cs_int_t  *const nbrloc,       /* --> nombre de valeurs  recevoir     */
       cs_real_t *const vardis,       /* --> variable distante ( envoyer)    */
       cs_real_t *const varloc        /* <-- variable locale ( recevoir)     */
);


/*============================================================================
 *  Prototypes de fonctions publiques
 *============================================================================*/

/*----------------------------------------------------------------------------
 * Ajout d'un couplage.
 *
 * On autorise les couplages soit avec des groupes de processus totalement
 * distincts du groupe principal (correspondant  cs_glob_base_mpi_comm),
 * soit avec ce mme groupe.
 *----------------------------------------------------------------------------*/

void  cs_couplage_ajoute
(
 const cs_int_t   rang_deb            /* --> rang du premier processus coupl */
);


/*----------------------------------------------------------------------------
 * Suppression des couplages.
 *----------------------------------------------------------------------------*/

void cs_couplage_detruit_tout
(
 void
);


#endif /* __CS_COUPLAGE_H__ */
